@@ -15,17 +15,14 @@ use lib 'blib/lib', 'blib/arch';
 use strict;
 use warnings;
 use Carp;
-use Algorithm::DecisionTree 3.30;
+use Algorithm::DecisionTree;
 use List::Util qw(reduce min max);
 
-our $VERSION = '3.30';
-
-@BoostedDecisionTree::ISA = ('Algorithm::DecisionTree');
+our $VERSION = '3.40';
 
+@Algorithm::BoostedDecisionTree::ISA = ('Algorithm::DecisionTree');
 
 ############################################   Constructor  ##############################################
-
-# Constructor:
 sub new { 
     my ($class, %args) = @_;
     my @params = keys %args;
@@ -48,6 +45,7 @@ sub new {
     bless $instance, $class;
 }
 
+##############################################  Methods  #################################################
 sub get_training_data_for_base_tree {
     my $self = shift;
     die("Aborted. get_training_data_csv() is only for CSV files") unless $self->{_training_datafile} =~ /\.csv$/;
@@ -420,9 +418,7 @@ sub get_all_class_names {
     return $self->{_all_trees}->{0}->{_class_names};
 }
 
-
-################################################ Utility Routines ##############################################
-
+############################################## Utility Routines ##########################################
 # checks whether an element is in an array:
 sub contained_in {
     my $ele = shift;
@@ -490,7 +486,7 @@ sub check_for_illegal_params {
 ##  and the same field in all other records is an ID number for the record.
 sub cleanup_csv {
     my $line = shift;
-    $line =~ tr/()[]{}/      /;
+    $line =~ tr/()[]{}'/       /;
     my @double_quoted = substr($line, index($line,',')) =~ /\"[^\"]+\"/g;
     for (@double_quoted) {
         my $item = $_;
