@@ -20,8 +20,6 @@ use Algorithm::DecisionTree 3.30;
 our $VERSION = '3.30';
 
 ############################################   Constructor  ##############################################
-
-# Constructor:
 sub new { 
     my ($class, %args) = @_;
     my @params = keys %args;
@@ -46,6 +44,7 @@ sub new {
     }, $class;
 }
 
+##############################################  Methods  #################################################
 sub get_training_data_for_bagging {
     my $self = shift;
     die("Aborted. get_training_data_csv() is only for CSV files") unless $self->{_training_datafile} =~ /\.csv$/;
@@ -327,6 +326,7 @@ sub get_all_class_names {
     return $self->{_all_trees}->{0}->{_class_names};
 }
 
+#########################################  Utility Routimes  #############################################
 # Returns an array of two values, the min and the max, of an array of floats
 sub minmax {
     my $arr = shift;
@@ -408,7 +408,7 @@ sub fisher_yates_shuffle {
 ##  and the same field in all other records is an ID number for the record.
 sub cleanup_csv {
     my $line = shift;
-    $line =~ tr/()[]{}/      /;
+    $line =~ tr/()[]{}'/       /;
     my @double_quoted = substr($line, index($line,',')) =~ /\"[^\"]+\"/g;
     for (@double_quoted) {
         my $item = $_;
