@@ -21,8 +21,6 @@ use Algorithm::DecisionTree 3.30;
 our $VERSION = '3.30';
 
 ############################################   Constructor  ##############################################
-
-# Constructor:
 sub new { 
     my ($class, %args) = @_;
     my @params = keys %args;
@@ -49,6 +47,7 @@ sub new {
     }, $class;
 }
 
+##############################################   Methods  ################################################
 sub get_training_data_for_N_trees {
     my $self = shift;
     die("Aborted. get_training_data_csv() is only for CSV files") unless $self->{_training_datafile} =~ /\.csv$/;
@@ -397,6 +396,7 @@ sub get_majority_vote_classification {
     return $sorted_by_votes_decision_classes[0];
 }
 
+########################################  Utility Routines  ##############################################
 sub sample_index {
     my $arg = shift;
     $arg =~ /_(.+)$/;
@@ -465,7 +465,7 @@ sub check_for_illegal_params {
 ##  and the same field in all other records is an ID number for the record.
 sub cleanup_csv {
     my $line = shift;
-    $line =~ tr/()[]{}/      /;
+    $line =~ tr/()[]{}'/       /;
     my @double_quoted = substr($line, index($line,',')) =~ /\"[^\"]+\"/g;
     for (@double_quoted) {
         my $item = $_;
